Django Kubernetes Manager
===================================

**Modules**
------------

Models
----------------------------------------------

.. automodule:: django_kubernetes_manager.models.base
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: django_kubernetes_manager.models.target_cluster
  :members:
  :undoc-members:
  :show-inheritance:

Serializers
----------------------------------------------

.. automodule:: django_kubernetes_manager.serializers
   :members:
   :undoc-members:
   :show-inheritance:

Views
----------------------------------------

.. automodule:: django_kubernetes_manager.views.model_views
  :members:
  :undoc-members:
  :show-inheritance:

.. automodule:: django_kubernetes_manager.views.func_views
  :members:
  :undoc-members:
  :show-inheritance:

Utils
----------------------------------------

.. automodule:: django_kubernetes_manager.utils
   :members:
   :undoc-members:
   :show-inheritance:
